% LIMMITCFGGET Get processing settings
%    cfg = limmitCfgGet(filename)
%
% INPUTS
%    filename: configuration rep name
%
% OUTPUTS
%    cfg: configuration structure
%_______________________________________________________________________

function cfg = limmitCfgGet(varargin)

% Configuration filename
if nargin
   filename = varargin{1};
else
   filename = './esa.limmit';
end

% Open the configuration file
fid = fopen(filename);
if fid == -1; cfg = []; return; end

% Read until the end of the file
while 1
   
   % Read a line from the rep
   tline = fgetl(fid);
   
   % Stop at the end of the file
   if ~ischar(tline), break, end;
   
   % Remove whitespaces
   tline = strtrim(tline);
   
   % Stop at the end of the file
   if strcmp(strtrim(tline), 'END'), break, end;
   
   % Skip comments
   if ~strncmp(tline, '!', 1) & length(tline)
      dummy = limmitStrGet(tline, 'sep', '=');
      name = strrep(dummy{1}(2:end), ' ', '');
      
      % Do not read comments
      val = limmitStrGet(dummy{2}, 'sep', '!');
      
      % Load comma separated values into an array
      comma = strfind(val{1}, ',');
      if ~isempty(comma)  
         numFlag = 1;
         val = strsep(val{1}, 'sep', ',');
         for i = 1:length(val)
            if isempty(str2num(val{i})); 
               numFlag = 0;
               val{i} = strtrim(val{i});
               val{i} = deblank(val{i});
            end
         end     
         if numFlag; 
            val = str2num(char(val))';
         end
      else
         numFlag = 1;
         val = val{1};
         if isempty(str2num(val)); 
            numFlag = 0;
            val = strtrim(val);
            val = deblank(val);
         end
         if numFlag; val = str2num(val); end
      end

      % Load configuration settings
      [names n] = limmitStrGet(name, 'sep', '.');
      switch n
        case 1
         cfg.(name) = val;
        case 2
         cfg.(names{1}).(names{2}) = val;
        case 3
         cfg.(names{1}).(names{2}).(names{3}) = val;
        case 4
         cfg.(names{1}).(names{2}).(names{3}).(names{4}) = val;
        case 5
         cfg.(names{1}).(names{2}).(names{3}).(names{4}).(names{5}) = val;
      end
      
   end
   
end

% Close the configuration rep
fclose(fid);
%_______________________________________________________________________