
% READ INPUT SST DATA

function hnd = seaeddy_dataread(hnd, pathname, filename)

% Load the data filename in the user structure
hnd.cfg.data_file = strrep(filename, '.', '_');

% Read the input sst data
dummy = strsep(filename, 'sep', '.');
filenamech4 = [dummy{1} '.' dummy{2} '.' dummy{3} '.ch4.' dummy{5}];
filenamech5 = [dummy{1} '.' dummy{2} '.' dummy{3} '.ch5.' dummy{5}];
rawch4 = readch([pathname filenamech4]);
rawch5 = readch([pathname filenamech5]);

% Sunset time
year = str2num([ '19' dummy{2}(1:2)]);
day = str2num(dummy{2}(3:5));
[mon, da, yr] = yearday2date(day, year);
[rhr,rmin,shr,smin]=sunrise(mon, da, yr, 37, 11);
sunsetTime = str2num([num2str(fix(shr)) num2str(fix(smin))]);
sunriseTime = str2num([num2str(fix(rhr)) num2str(fix(rmin))]);

% Image time
imageTime = str2num(dummy{3});

% SST
if imageTime > sunriseTime & imageTime < sunriseTime
   raw = 3.6139 * rawch4 - 2.5789 * rawch5;
else
   raw = 1.0346 * rawch4 + 2.5779 * (rawch5 - rawch5);
end

% xm = min(M1(:));
% xM = max(M1(:));
% ym = 15;
% yM = 25;
% raw = ym + (yM - ym) * (M1 - xm) / (xM - xm);

% Mask
raw(raw > hnd.cfg.temp_max) = hnd.cfg.temp_max;
raw(raw < hnd.cfg.temp_min) = hnd.cfg.temp_min;

% Get the land data
area = readch([hnd.cfg.data_path 'AREA.hdf']);

% Flag the land
raw(area == 1) = hnd.cfg.temp_min - 1;

% Noise filtering
dummy = double(raw(:,:,1));
b = .1*ones(size(dummy));
% hnd.cfg.evl_coe = str2num(get(findobj('Tag', 'evlcoeEdt'), 'String'));
% hnd.cfg.evl_iter = str2num(get(findobj('Tag', 'evliterEdt'), 'String'));
hnd.cfg.evl_coe = 0.85;
hnd.cfg.evl_iter = 18;
evl = evolve2D(dummy, 1, 1, hnd.cfg.evl_coe, hnd.cfg.evl_iter, [], [], 0, [], 0, [], [], 1, b);

% Load data into the user structure
hnd.sst.evl = evl;
hnd.sst.raw = raw;
hnd.sst.idx = seaeddy_coloridx(hnd.cfg, hnd.sst.raw);
hnd.sst.ref = seaeddy_coloridx(hnd.cfg, hnd.sst.evl);

% Info
seaeddy_info([filename ': data processed']);
%_______________________________________________________________________________
