% Read the configuration file
hnd.cfg = limmitConfRead('limmit.cfg');

% Create the Excell server
hnd.xls.server = actxserver('excel.application');

% Link to the Excell workbook
currenFolder = pwd;
cd(hnd.cfg.data_path)
hnd.xls.workbook = hnd.xls.server.Workbooks.Open([pwd  filesep hnd.cfg.xls_file]);
hnd.xls.server.visible = 1;

% Read data
dummy = hnd.xls.workbook.ActiveSheet.get('Range', 'A3:DY716');
[nR nC] = size(dummy.value);

% Raw weights
dat.wgtRaw = [dummy.value{:,9}]';

% Raw values
for iC =10:nC
   rawVal(:, iC) = [dummy.value{:,iC}]';
end

% Predefined intervals
defInt = [9.1,9.2;...
9.4,9.8;...
9.9,9.9;...
11.7,12.1;...
13,13.9;...
15.6,16.4;...
21.6,22.6;...
26.8,28.8;...
32.2,34.8;...
37,38.9;...
44.9,47.6;...
53.2,56;...
60.8,62.7;...
67.1,67.4;...
69.3,70.7;...
74,76.8;...
79.1,79.1;...
92.1,92.1;...
148.5,169.7];
nInt = length(defInt);

% Processing settngs
nKer = 30;
intCol = limmitColors(nKer, {'w','k'});

% All weights and values
flags = rawVal ~= 0;
values = sum(flags, 2);
dat.allWgt = 10*min(dat.wgtRaw):1:10*max(dat.wgtRaw);
for iW = 1:length(dat.allWgt)
   idx = find((dat.allWgt(iW)==10*dat.wgtRaw) == 1);
   if idx
      dat.allVal(iW) = values(idx);
   else
      dat.allVal(iW) = 0;
   end
end
dat.allWgt = dat.allWgt/10;

% Show results
name = 'def'
hFig = limmitFigCreate()
v = [0 255 0 25];
axis(v);
hold on;
set(gca, 'XMinorGrid', 'off', 'YMinorGrid', 'off')

% Show bands
intTag = [];
intLab = [];
for iInt = 1:nInt
   pos =  [defInt(iInt, 1) 0 defInt(iInt, 2) - defInt(iInt, 1) v(4)];
   if pos(3)
      hLin = plot([defInt(iInt, 1) defInt(iInt, 1)], v(3:4));
      set(hLin, 'lineW', 2, 'Color', intCol(iInt, :));
      hRct = rectangle('Position', pos);
      set(hRct, 'EdgeColor', 'none', 'FaceColor', intCol(iInt, :));
      intLab{iInt} = sprintf('%.1f-%.1f', defInt(iInt, 1), defInt(iInt, 2));
   else
      hLin = plot([defInt(iInt, 1) defInt(iInt, 1)], v(3:4));
      set(hLin, 'lineW', 2, 'Color', intCol(iInt, :));
      intLab{iInt} = sprintf('%.1f', defInt(iInt, 1));
   end
   intTag(iInt) = hLin;
end
hL = legend(intTag, intLab, 'Location', 'EastOutside');
set(hL, 'fonts', 9);

% Plot all points
hPts = plot(dat.allWgt, dat.allVal, 'ko');
set(hPts, 'MarkerSize', 4);

% Title and labels
xlabel('Weight [kDa]')
ylabel('Proteomics expression [N. of cases]')
title('Default intervals');

% Print the figure
limmitFigPrint(['../doc/fig/' name], hFig);

% Data points
dat.pts = [];
cnt = 1;
for iW = 1:length(dat.allWgt)
   if dat.allVal(iW) > 1
      for iVal = 1:dat.allVal(iW)
         dat.pts(cnt) = dat.allWgt(iW) + 0.05 * randn;
         cnt = cnt + 1;
      end
   end
end

% Gaussian mixture model
input_dim = 1;
mix = gmm(input_dim, nKer, 'spherical');
options = foptions;
options(14) = 5;
mix = gmminit(mix, dat.pts', options);
options = zeros(1, 18);
options(1)  = 1;		% Prints out error values.
options(14) = 50;		% Max. Number of iterations.
[mix, options, errlog] = gmmem(mix, dat.pts', options);
z = gmmprob(mix, dat.allWgt');
[post tmp] = gmmpost(mix, dat.allWgt');
[xmax,imax,xmin,imin] = extrema(z);

% Show results
name = 'gmm';
hFig = limmitFigCreate(name);
v = [0 255 0 25];
axis(v);
hold on

% Show bands
intTag = [];
intLab = [];
minWgt = sort(dat.allWgt(imin));
for iMin = 1:length(minWgt) - 1
   pos =  [minWgt(iMin) 0 minWgt(iMin + 1) - minWgt(iMin) v(4)];
   if pos(3)
      hLin = plot([minWgt(iMin) minWgt(iMin)], v(3:4));
      set(hLin, 'lineW', 2, 'Color', intCol(iMin, :));
      hRct = rectangle('Position', pos);
      set(hRct, 'EdgeColor', 'none', 'FaceColor', intCol(iMin, :));
      intLab{iMin} = sprintf('%.1f-%.1f', minWgt(iMin), minWgt(iMin + 1));
   else
      hLin = plot([minWgt(iMin) minWgt(iMin)], v(3:4));
      set(hLin, 'lineW', 2, 'Color', intCol(iMin, :));
      intLab{iMin} = sprintf('%.1f', minWgt(iMin));
   end
   intTag(iMin) = hLin;
end
hL = legend(intTag, intLab, 'Location', 'EastOutside');
set(hL, 'fonts', 9);

% Plot all points
hPts = plot(dat.allWgt, dat.allVal, 'ko');
set(hPts, 'MarkerSize', 4);

h1 = plot(dat.allWgt, 250*z, 'k');
set(h1, 'linew', 3);
h2 = plot(dat.allWgt, 250*z, 'w');
set(h2, 'linew', 1);

% Title and labels
xlabel('Weight [kDa]')
ylabel('Proteomics expression [N. of cases]')
title('GMM intervals');

% Print the figure
limmitFigPrint(['../doc/fig/' name], hFig);
