% Read the configuration file
hnd.cfg = limmitConfRead('limmit.cfg');

% Create the Excell server
hnd.xls.server = actxserver('excel.application');

% Link to the Excell workbook
currenFolder = pwd;
cd(hnd.cfg.data_path)
hnd.xls.workbook = hnd.xls.server.Workbooks.Open([pwd  filesep hnd.cfg.xls_file]);
hnd.xls.server.visible = 1;

% Read data
dummy = hnd.xls.workbook.ActiveSheet.get('Range', 'AU5:DL139');
[nR nC] = size(dummy.value);
data = zeros(nR, nC);
for iR = 1:nR
   data(iR, :) = [dummy.value{iR, :}];
end
idxVld = sign(sum(data < 0, 2));
data = data(idxVld ~= 1, :);

% Labeling info
label = hnd.xls.workbook.ActiveSheet.get('Range', 'B5:B139');
sumLab = {'Public', 'Private', 'Total'}

% Histograms
for iSum = 0:2
   
   % TWH
   name = 'twh';
   twhCls = listcmp(label.value, {'TWH'});
   twhCls = find(twhCls(idxVld ~= 1) == 1);
   hFig = limmitFigCreate(name);
   [yVal xVal] = hist(data(twhCls, end - iSum), 5);
   yVal = 100 * yVal ./ sum(yVal);
   hBr = bar(xVal, yVal, 1);
   set(hBr, 'FaceColor', 'w')
   xlabel('Value')
   ylabel('Fraction [%]');
   title(['TWH - ' sumLab{iSum + 1}]);
   axis([0 60 0 40]);
   limmitFigPrint(['../doc/fig/' name sumLab{iSum + 1}], hFig);

   % SHM
   name = 'shm';
   shmCls = listcmp(label.value, {'Sham TWH'});
   shmCls = find(shmCls(idxVld ~= 1) == 1);
   hFig = limmitFigCreate(name);
   [yVal xVal] = hist(data(shmCls, end - iSum), 5);
   yVal = 100 * yVal ./ sum(yVal);
   hBr = bar(xVal, yVal, 1);
   set(hBr, 'FaceColor', 'w')
   xlabel('Value')
   ylabel('Fraction [%]');
   title(['Sham TWH - ' sumLab{iSum + 1}]);
   axis([0 60 0 40]);
   limmitFigPrint(['../doc/fig/' name sumLab{iSum + 1}], hFig);

end

% TWH
twhCls = listcmp(label.value, {'TWH'});
twhCls = find(twhCls(idxVld ~= 1) == 1);
xTwhPub = data(twhCls, end - 0);
yTwhPri = data(twhCls, end - 1);

% SHM
shmCls = listcmp(label.value, {'Sham TWH'});
shmCls = find(shmCls(idxVld ~= 1) == 1);
xShmPub = data(shmCls, end - 0);
yShmPri = data(shmCls, end - 1);

% Scatter plot
name = 'twhAndShm';
hFig = limmitFigCreate(name);
hTwh = plot(xTwhPub, yTwhPri, 'ro');
set(hTwh, 'MarkerFaceColor', 'r')
hold on
hShm = plot(xShmPub, yShmPri, 'bo');
set(hShm, 'MarkerFaceColor', 'b');
xlabel('Public')
ylabel('Private');
hL = legend({'TWH', 'Shm TWH'});
set(hL, 'FontSize', 12)
set(hL, 'location', 'NorthWest');
axis square;
limmitFigPrint(['../doc/fig/' name], hFig);

% Close all
hnd.xls.workbook.Saved = 1;
hnd.xls.workbook.Save;
hnd.xls.workbook.Close;
hnd.xls.server.Quit;
hnd.xls.server.delete;