
function [Fields nFields] = fieldsfind(filename, varargin)

% FIELDSFIND finds the data field names. 

%	Copyright (c) Davide D'Alimonte (2006)

% Input arguments
headerId = '!';
lambdaSep = '';
headFlag = 1;
delimiter = '	';
if nargin 
   for i=1:length(varargin);   
      switch varargin{i};
        case 'headerId'
         headerId = varargin{i+1};
        case 'lambdaSep'
         lambdaSep = varargin{i+1};        
        case 'header'
         headFlag = varargin{i+1};        
        case 'endHeader'
         endHeader = varargin{i+1};        
        case 'delimiter'
         delimiter = varargin{i+1};        
      end
   end
end

% Open the input file (exit if the file does not exist!)
fid = fopen(filename);
if fid < 0
   disp([filename ' does not exist!'])
   return
end

% Go to the end of the header
if isnumeric(endHeader)
   for i = 1:endHeader
      tLine = fgetl(fid);
   end
else
   nHeader = length(endHeader);
   cnt = 1;
   while 1
      tLine = fgetl(fid);
      cnt = cnt + 1;
      if cnt > 100
         disp(['Something wrong with ' filename]);
         break
      end
      if length(tLine) == nHeader
         if strncmp(tLine(1:nHeader), endHeader, nHeader)
            break
         end
      end
   end
end

% Get the field List
tLine = fgetl(fid);
[Fields nFields] = strsep(tLine, 'sep', delimiter);

% Substitute the lambda separator with an underscore
if length(lambdaSep)
   for iFields = 1:nFields   
      pos = strfind(Fields{iFields}, lambdaSep);
      if length(pos) > 0
         Fields{iFields} = lower([Fields{iFields}(1:pos-1) '_'  ...
                             Fields{iFields}(pos+1:end)]);
      else
         Fields{iFields} = lower(Fields{iFields});
      end
   end
end

% Remove dashes
for iFields = 1:nFields   
   pos = strfind(Fields{iFields}, '-');
   if length(pos) > 0
      Fields{iFields} = lower(strrep(Fields{iFields}, '-', ''));
   else
      Fields{iFields} = lower(Fields{iFields});
   end
end

% Remove parentesis
for iFields = 1:nFields   
   pos = strfind(Fields{iFields}, '(');
   if length(pos) > 0
      Fields{iFields} = lower(strrep(Fields{iFields}, '(', ''));
   else
      Fields{iFields} = lower(Fields{iFields});
   end
end
for iFields = 1:nFields   
   pos = strfind(Fields{iFields}, ')');
   if length(pos) > 0
      Fields{iFields} = lower(strrep(Fields{iFields}, ')', ''));
   else
      Fields{iFields} = lower(Fields{iFields});
   end
end
for iFields = 1:nFields   
   pos = strfind(Fields{iFields}, '[');
   if length(pos) > 0
      Fields{iFields} = lower(strrep(Fields{iFields}, '[', ''));
   else
      Fields{iFields} = lower(Fields{iFields});
   end
end
for iFields = 1:nFields   
   pos = strfind(Fields{iFields}, ']');
   if length(pos) > 0
      Fields{iFields} = lower(strrep(Fields{iFields}, ']', ''));
   else
      Fields{iFields} = lower(Fields{iFields});
   end
end

for iFields = 1:nFields   
   pos = strfind(Fields{iFields}, '1/m');
   if length(pos) > 0
      Fields{iFields} = lower(strrep(Fields{iFields}, '1/m', ''));
   else
      Fields{iFields} = lower(Fields{iFields});
   end
end

% Remove dots
for iFields = 1:nFields   
   pos = strfind(Fields{iFields}, '.');
   if length(pos) > 0
      Fields{iFields} = lower(Fields{iFields}(1:pos-1));
   else
      Fields{iFields} = lower(Fields{iFields});
   end
end

for iFields = 1:nFields   
   pos = strfind(Fields{iFields}, '/');
   if length(pos) > 0
      Fields{iFields} = lower(strrep(Fields{iFields}, '/', '_over_'));
   else
      Fields{iFields} = lower(Fields{iFields});
   end
end
