%statvisu: functio for statistical parameters visualization

function coe = statvisu(varargin)

%default input variables
x = varargin{1};
y = varargin{2};
v = varargin{3};

%set flag for statistical parameters visualization
log = 1;
relerr = 1;
unsrelerr = 1;
rmsrd = 1;
rms = 1;
corrcoe = 1;
nsamp = 1;
FontSize = get(0, 'defaultaxesfontsize')-2;
if nargin>3
   relerr = 0;
   rmsrd = 0;
   rms = 0;
   corrcoe = 0;
   nsamp = 0;
   for i = 4:1:nargin
      switch varargin{i}
         case 'FontSize';
            FontSize = varargin{i+1};			
         case 'nolog';
            log = 0;			
         case 'nsamp';
            nsamp = 1;			
         case 'relerr';
            relerr = 1;			
         case 'unsrelerr';
            unsrelerr = 1;			
         case 'rmsrd';
            rmsrd = 1;
         case 'rms';
            rms = 1;
         case 'corrcoe';
            corrcoe = 1;
         otherwise
      end
   end
   
end

%statistical parameters
coe = stat(x, y); %box on

%label position
if log ==  1
   v = log10(v);% - log
   xpos = 10.^(v(1)+0.08*(v(2)-v(1)));% - log
end
if log ==  0
   xpos = v(1)+0.08*(v(2)-v(1));
end

ydelta = 0.07*(v(4)-v(3));
xdelta = 0.08*(v(2)-v(1));
ytmp = v(4)-ydelta/2.5;
xtmp = v(1)+xdelta/3;

%white box around labels
y = [ytmp-5*ydelta ytmp-.5*ydelta ytmp-.5*ydelta ytmp-5*ydelta];
x = [xtmp+.35*xdelta xtmp+.35*xdelta xtmp+3.5*xdelta xtmp+3.5*xdelta];
if log ==  1
   x = 10.^x;
   y = 10.^y;
end
h = patch(x, y, [1 1 1], 'EdgeColor', [1 1 1]);

ypos = ytmp;
if nsamp		%n samples
   ypos = ypos-ydelta;
   nsamp = sprintf('%i', coe.nsamp);
   if log ==  1
      newypos = 10.^ypos;
   end
   if log ==  0
      newypos = ypos;
   end
   text(xpos, newypos, strcat('N = ', nsamp), 'FontSize', FontSize);% - log
end
if relerr		%relative error
   ypos = ypos-ydelta;
   if log ==  1
      newypos = 10.^ypos;
   end
   if log ==  0
      newypos = ypos;
   end
   err = sprintf('%.0f', 100*coe.relerr);
   text(xpos, newypos, ['\it{\epsilon}\rm = ', err, ' %'], 'FontSize', FontSize);
end
if unsrelerr		%absolute relative error
   ypos = ypos-ydelta;
   if log ==  1
      newypos = 10.^ypos;
   end
   if log ==  0
      newypos = ypos;
   end
   err = sprintf('%.0f', 100*coe.unsrelerr);
   text(xpos, newypos, ['\it{\delta}\rm = ', err, ' %'], 'FontSize', FontSize);
end
if corrcoe		%correlation coefficient
   ypos = ypos-ydelta;
   if log ==  1
      newypos = 10.^ypos;
   end
   if log ==  0
      newypos = ypos;
   end
   detcoe = sprintf('%.2f', coe.detcoe);
   val = strcat('r^{2} = ', detcoe);
   text(xpos, newypos, val, 'FontSize', FontSize);% - log     
end
if rms		%correlation coefficient
   ypos = ypos-ydelta;
   if log ==  1
      newypos = 10.^ypos;
   end
   if log ==  0
      newypos = ypos;
   end
   rmscoe = sprintf('%.2f', coe.rms);
   val = strcat('RMS = ', rmscoe);
   text(xpos, newypos, val, 'FontSize', FontSize);% - log     
end
%______________________________________________________________________________
